@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "eventmovejob.h"
@@ -83,7 +83,7 @@ EventMoveJob::EventMoveJob(const EventPtr &event, const QString &sourceCalendarI
     ModifyJob(account, parent),
     d(new Private(this))
 {
-    d->eventsIds << event->uid();
+    d->eventsIds << event->id();
     d->source = sourceCalendarId;
     d->destination = destinationCalendarId;
 }
@@ -95,7 +95,7 @@ EventMoveJob::EventMoveJob(const EventsList &events, const QString &sourceCalend
     d(new Private(this))
 {
     for (const EventPtr &event : events) {
-        d->eventsIds << event->uid();
+        d->eventsIds << event->id();
     }
     d->source = sourceCalendarId;
     d->destination = destinationCalendarId;
